pub struct CreateFeedSpecification {
pub feed_type: String,
pub marketplace_ids: Vec<String>,
pub input_feed_document_id: String,
pub feed_options: Option<HashMap<String, String>>,
}Fields
feed_type: StringThe feed type.
marketplace_ids: Vec<String>A list of identifiers for marketplaces that you want the feed to be applied to.
input_feed_document_id: StringThe document identifier returned by the createFeedDocument operation. Encrypt and upload the feed document contents before calling the createFeed operation.
feed_options: Option<HashMap<String, String>>Additional options to control the feed. For feeds that use the feedOptions parameter, you can find the parameter values in the feed description in feedType values.
Implementations